#### Integrations

##### Palo Alto Networks PAN-OS

*New Commands*

The following commands have been added to provide abilities to identify multiple types of dynamic content with available updates on Palo Alto Networks PAN-OS firewalls and then download/install them.  These commands support built-in polling.
- Added command **pan-os-get-rule-hitcounts**, which returns hit counts for policy rules on firewalls. When connected to a Panorama instance this command retrieves hit count data from all connected firewalls.
- Added command **pan-os-disable-rule**, which can be used to set a policy rule as disabled.

*Enhancements to Existing Commands*
- Added support to **pan-os-delete-rule** to delete additional types of policy rules as well as delete rules from firewalls connected to Panorama.  In addition to security policy rules, this command can now also delete the following types:
    - application-override
    - authentication
    - decryption
    - nat
    - pbf
- Enhanced the  **pan-os-platform-get-ha-state** command to be capable of retrieving information about connected HA peers when the Integration instance is connected directly to a firewall. Previously this command only returned the peer's serial number in context output if it was connected to a Panorama system.



#### Scripts

##### New: PAN-OS-AnalyzeRuleHitCounts

- New: Added a new script, PAN-OS-AnalyzeRuleHitCounts, that processes the context output from !pan-os-get-rulehitcounts and returns data about unused local rules, unused rules from Panorama, and rules from Panorama that have hits on some firewalls but not all.


##### New: PAN-OS-GetAvailablePANOSSoftware

- New: Added a new script, PAN-OS-GetAvailablePANOSSoftware, that is a wrapper for the 'pano-os-platform-get-available-software' command, adding options to return only images newer than is currently installed to minimize the amount of context data generated.


##### New: PAN-OS-GetDeviceDiskSpace

- New: Added a new script, PAN-OS-GetDeviceDiskSpace, that fetches disk space info from the target device and returns all information or a subset as specified in command arguments.



#### Playbooks

##### New: PAN-OS - Download and Install Dynamic Content Updates

This playbook automates the download and installation of the following Dynamic Update types on Palo Alto firewalls:
  - App/Threat
  - Anti-Virus
  - WildFire
  - GlobalProtect Clientless VPN

Use the "itemsToUpdate" input to control which update type(s) to download and install. All types are updated by default.

NOTE: This playbook is intended for use with a single PAN-OS Integration Instance.

##### New: PAN-OS - Firewall Upgrade Readiness Checks

This playbook uses the PAN-OS integration to check NGFW device conditions that can affect its readiness to perform a PAN-OS upgrade. Included checks examine the following:
1. Available disk space for the target version (base image + release image)
2. Presence of any uncommitted configuration changes
3. Whether device has an active Support license
4. Whether NTP is configured and synced
5. Whether the latest App/Threat dynamic update is installed
6. For devices in HA groups, check that devices in the group have:
    1. App/Threat, AntiVirus, and GlobalProtect Client are at the same level and compatible for HA failover
    2. Running configuration synchronized among peers

Playbook output includes a register of the checks performed, a brief description, and their result.

NOTE: This playbook is intended for use with a single PAN-OS Integration Instance.

##### New: PAN-OS - Identify Unused Policy Rules

The playbook collects and analyzes Palo Alto Networks NGFW policy rule hitcount information and generates a summary of unused rules for potential clean-up. Policy rules are classified into three categories:
1. Unused Local Rules - Rules configured locally on firewalls
2. Unused Panorama Rules - Rules pushed to one or more firewalls from Panorama that have zero hits on all firewalls.
3. Used Panorama Rules - Rules pushed to one or more firewalls from Panorama that have hits on some firewalls but not all.
    i. These rules may be pushed to firewalls where they are not needed and should be considered for clean-up.

For firewalls in HA pairs, rules are only considered unused if all members of the HA group have zero hits for it.

##### New: PAN-OS - Run Security Configuration Hygiene Checks

This playbook executes hygiene check commands using the PAN-OS integration and identifies items configured in a manner that do not meet minimum security best practices. It looks for the following:
1. Log Forwarding Profiles
  i. Profiles without Enhanced Logging enabled
  ii. Profiles with no match list (rules) configured
  iii. Profiles that do not include rules to forward Traffic or Threat logs
2. Security Zones with no Log Forwarding Profile assigned
3. Spyware Profiles that do not:
  i. Block signatures of Critical and High severity
  ii. Alert on (or block) signatures of Medium and Low severity
4. URL Filtering Profiles do not block the default URL categories blocked in the pre-defined profile
5. Vulnerability Profiles that do not:
  i. Block signatures of Critical and High severity
  ii. Alert on (or block) signatures of Medium and Low severity
6. Security Rules that do not:
  i. Log at Session End
  ii. Have a Log Forwarding Profile assigned
  iii. Have Security Profiles assigned for Anti Virus, Spyware, Vulnerability, and URL Filtering (or a group that includes each)

NOTE: This playbook is intended for use with a single PAN-OS Integration Instance.